autowisp.magnitude_fitting.util module — AutoWISP documentation

# autowisp.magnitude_fitting.util module

Functions for formatting magnitude fitting inputs as needed.

autowisp.magnitude_fitting.util._init_magfit_sources(source_data)

  Return empty array properly formatted to hold the given sources.

autowisp.magnitude_fitting.util._parse_phot_column(colname)

  Return the magfit iteration of the given phot column (-1 if not phot).

autowisp.magnitude_fitting.util.format_master_catalog(cat_sources, source_id_parser=None)

  Return the catalogue info in the given file formatted for magfitting.

autowisp.magnitude_fitting.util.get_magfit_sources(data_reduction_file, magfit_iterations='all', **path_substitutions)

  Return the sources in the given DR file formatted for magfit.

autowisp.magnitude_fitting.util.get_master_photref(photref_fname)

  Read a FITS photometric reference created by MasterPhotrefCollector.

autowisp.magnitude_fitting.util.get_single_photref(data_reduction_file, **path_substitutions)

  Create a photometric reference out of the raw photometry in a DR file.